import random
verbose = False

class DicePool:
   def __init__(self,count,sides):
      self.count = count
      self.sides = sides
   
   def rollPool(self):
      results = []
      for i in range(0, self.count):
         die = self.getRoll()
         results.append(die)
      results.sort()
      return results
          
   def getRoll(self):
      return random.randint(1, self.sides)

class Situation:
   def __init__(self,totalDice,playerDice):
      self.sides = 6
      self.totalDice = totalDice
      self.playerDice = playerDice
      self.playerPool = DicePool(playerDice,self.sides)
      self.gmPool = DicePool(totalDice - playerDice,self.sides)
      self.results = {}
      self.repeat = 0
      for victoryPointsForPlayer in range (1-totalDice,totalDice):
         self.results[victoryPointsForPlayer] = 0
   
   def report(self):
      print ''
      print 'Count of how many times player scores X victory points with %d dice (%d total tests)' % (self.playerDice,self.repeat)
      for victoryPointsForPlayer in range (1-totalDice,totalDice):
         count = self.results[victoryPointsForPlayer]
         if (count != 0):
            percentage = count * 100.0 / self.repeat
            line = ' %2d\t%d\t%6.1f%%' % (victoryPointsForPlayer,count,percentage) 
            print line
      
   def run(self,repeat):
      self.repeat += repeat
      for count in range(0,repeat):
         victoryPointsForPlayer = self.test()
         self.results[victoryPointsForPlayer] += 1
   
   def test(self):
      gmRoll = self.gmPool.rollPool()
      playerRoll = self.playerPool.rollPool()
      gmHigh = gmRoll.pop()
      playerHigh = playerRoll.pop()
      while gmHigh == playerHigh:
         try:
            gmHigh = gmRoll.pop()
         except:
            gmHigh = 0
         try:
            playerHigh = playerRoll.pop()
         except:
            playerHigh = 0
      
      victoryPointsForPlayer = 0
      if gmHigh > playerHigh:
         victoryPointsForPlayer = -1
         for die in gmRoll:
            if (die > playerHigh):
               victoryPointsForPlayer -= 1
      elif playerHigh > gmHigh:
         victoryPointsForPlayer = 1
         for die in playerRoll:
            if (die > gmHigh):
               victoryPointsForPlayer += 1
      return victoryPointsForPlayer
      
Counts = {}
random.seed()
repeat = 1000000
totalDice = 7
for playerDice in range(1,totalDice):
   situation = Situation(totalDice,playerDice)
   situation.run(repeat)
   situation.report()